package gendarme

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Gendarme.MSource

Minimal encoder signature

Sourcetype t

The internal encoder type

Sourceval unpack : target -> t

Unpack an internal value

Sourceval pack : t -> target

Pack an internal value

Sourceval marshal : ?v:'a -> 'a ty -> t

Marshal a value

Sourceval unmarshal : ?v:t -> 'a ty -> 'a

Unmarshal a value

Sourceval marshal_safe : ?v:'a -> 'a ty -> t

Marshal a value in an way safe for the encoder

Sourceval unmarshal_safe : ?v:t -> 'a ty -> 'a

Unmarshal a value in a way safe for the encoder