You can search for identifiers within the package.
in-package search v0.2.0
gendarme
Gendarme.M
Minimal encoder signature
type t
The internal encoder type
val unpack : target -> t
Unpack an internal value
val pack : t -> target
Pack an internal value
val marshal : ?v:'a -> 'a ty -> t
Marshal a value
val unmarshal : ?v:t -> 'a ty -> 'a
Unmarshal a value
val marshal_safe : ?v:'a -> 'a ty -> t
Marshal a value in an way safe for the encoder
val unmarshal_safe : ?v:t -> 'a ty -> 'a
Unmarshal a value in a way safe for the encoder